#!/usr/bin/env python
# To use:
#       python setup.py install
#

import distutils, os, sys, re
from distutils.core import setup, Extension
from distutils.command.sdist import sdist

class PreReleaseCheck:

    def __init__(self, distribution):
        self.fails = 0
        self.setup_rev = distribution.get_version()
        self.check_rev('doc/conf.py', r'^(?:version|release)\s*=\s*\'(.*)\'')
        self.check_rev('doc/installation.rst', 
                       r'tar xz.*albatross-(.*)\.tar\.gz')
        self.check_rev('doc/installation.rst', r'``albatross-(.*)``')
        self.check_rev('albatross/__init__.py', r'__version__ = \'(.*)\'')
        if self.fails:
            sys.exit(1)

    def extract_revs(self, filename, pattern):
        regexp = re.compile(pattern)
        line_num = 0
        for line in open(filename):
            line_num += 1
            match = regexp.search(line)
            if match:
                yield (line_num, match.group(1), line)

    def check_rev(self, filename, pattern):
        matches = 0
        for line_num, file_rev, line in self.extract_revs(filename, pattern):
            matches += 1
            if file_rev != self.setup_rev:
                self.fails += 1
                print >> sys.stderr, \
                    ("%s:%d version %r does not match setup.py %r\n    %r" % 
                        (filename, line_num, file_rev, self.setup_rev, line))
        if not matches:
            self.fails += 1
            print >> sys.stderr, \
                ("Could not locate version string in %s with:\n    %s" %
                            (filename, pattern))


class my_sdist(sdist):

    def run(self):
        PreReleaseCheck(self.distribution)
        self.announce("Pre-release checks pass!")
        sdist.run(self)


setup(name = "albatross",
    version = "1.40",
    maintainer = "Object Craft",
    maintainer_email = "albatross@object-craft.com.au",
    description = "Albatross Web Toolkit",
    url = "http://www.object-craft.com.au/projects/albatross/",
    packages = ['albatross', 'albatross.ext'],
    scripts = ['session-server/al-session-daemon',
               'standalone-server/al-httpd'],
    license = 'BSD - see file LICENCE',
    cmdclass = {'sdist': my_sdist},
)
