#
# Copyright 2001 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#
# 
# Basic functionality tests.
#
# $Id: basic.py 15398 2010-01-22 06:20:43Z andrewm $

import unittest
import albatross
import template_common
import time

class BasicCase(template_common.TemplateTestCommon):

    template_dir = "basic"

    def test_file(self):
        self.html_test("file.html", "plain\n")

    def test_nxfile(self):
        self.tmpl_exc("nxfile.html")

    def test_const_value(self):
        self.html_test("const-value.html", "27")

    def test_img_null_attr(self):
        self.ctx.locals.imgsrc = ''
        self.html_test("img-expr.html", '<img alt="" ismap src="" />')

    def test_img_escape(self):
        self.ctx.locals.imgsrc = '&<>"\'?'
        self.html_test("img-expr.html", 
                       '<img alt="" ismap src="&amp;&lt;&gt;&quot;&#39;?" />')

    def test_attr_quote(self):
        self.html_test("attr-quote.html", "abcdefghijkl")

    def test_value_no_expr(self):
        self.tmpl_exc("value-no-expr.html")

    def test_value_no_expr_sp(self):
        self.tmpl_exc("value-no-expr-sp.html")

    def test_var_value(self):
        self.ctx.locals.x = 17
        self.html_test("var-value.html", "17")

    def test_var_float(self):
        self.ctx.locals.x = 2.1
        self.html_test("var-value.html", "2.1")

    def test_var_string(self):
        self.ctx.locals.x = "abc"
        self.html_test("var-value.html", "abc")

    def test_var_escape(self):
        self.ctx.locals.x = '<img src="http://rude.pictures.r.us/">'
        self.html_test("var-value.html", "&lt;img src=&quot;http://rude.pictures.r.us/&quot;&gt;")

    def test_var_noescape(self):
        self.ctx.locals.x = '<img src="http://rude.pictures.r.us/">'
        self.html_test("var-value-noescape.html", '<img src="http://rude.pictures.r.us/">')

    def test_date(self):
        t = time.strftime("%A, %B %d, %Y, %I:%M%p", 
                          time.localtime(996113203.67031395))
        self.html_test("date.html", t)

    def test_comment(self):
        self.html_test("comment.html", "one\nfour\n")

    def test_exec(self):
        self.html_test("exec.html", " 2 3 5 7")

    def test_href(self):
        self.str_html_test('<al-a href="xxx">link</al-a>', 
                           '<a href="http://localhost/test/xxx">link</a>')

    def test_href_param(self):
        self.str_html_test('<al-a href="foo?">link</al-a>', 
                           '<a href="foo?">link</a>')

    def test_href_param_expr(self):
        self.ctx.locals.bah = 'foo?'
        self.str_html_test('<al-a expr="bah">link</al-a>', 
                           '<a href="foo?">link</a>')

    def test_href_param_expr_escape(self):
        self.ctx.locals.bah = '&<>"\'?'
        self.str_html_test('<al-a expr="bah">link</al-a>', 
                           '<a href="&amp;&lt;&gt;&quot;&#39;?">link</a>')

    def test_href_request(self):
        self.str_html_test('<al-a href="a=b">link</al-a>', 
                           '<a href="/test?a=b">link</a>')


if __name__ == '__main__':
    unittest.main()
