#
# Copyright 2001 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#
# 
# Form functionality tests.
#
# $Id: form.py 15398 2010-01-22 06:20:43Z andrewm $

import unittest
import albatross
import template_common

class InputCase(template_common.TemplateTestCommon):

    template_dir = "form"

    def test_input_text(self):
        self.ctx.locals.spam = "canned meat product"
        self.html_test("input-text.html", '<input name="spam" value="canned meat product" />')

    def test_input_text_escaping(self):
        self.ctx.locals.spam = '&<>"'
        self.html_test("input-text.html", '<input name="spam" value="&amp;&lt;&gt;&quot;" />')

    def test_input_text_zero(self):
        self.ctx.locals.spam = 0
        self.html_test("input-text.html", '<input name="spam" value="0" />')

    def test_input_text_expr(self):
        self.ctx.locals.str = "canned meat product"
        self.html_test("input-text-expr.html", '<input name="spam" value="canned meat product" />')

    def test_input_text_expr_escaping(self):
        self.ctx.locals.str = '&<>"\''
        self.html_test("input-text-expr.html", '<input name="spam" value="&amp;&lt;&gt;&quot;&#39;" />')

    def test_input_text_nameexpr(self):
        self.ctx.locals.str = 'spam'
        self.ctx.locals.num = 69
        self.ctx.locals.spam_69 = 'canned meat product'
        self.html_test("input-nameexpr-text.html", '<input type="text" name="spam_69" value="canned meat product" />')

    def test_input_text_nameexpr_escaping(self):
        self.ctx.locals.str = '&<>"\''
        self.str_html_test('<al-input type="text" nameexpr="str" value="">', 
               '<input type="text" name="&amp;&lt;&gt;&quot;&#39;" value="" />')

    def test_input_text_anyattr(self):
        self.ctx.locals.str = "canned meat product"
        self.str_html_test('<al-input type="text" classexpr="str" name="x">', 
               '<input type="text" class="canned meat product" name="x" />')

    def test_input_text_anyattr_escaping(self):
        self.ctx.locals.str = '&<>"\''
        self.str_html_test('<al-input type="text" classexpr="str" name="x">', 
              '<input type="text" class="&amp;&lt;&gt;&quot;&#39;" name="x" />')

    def test_input_password(self):
        self.html_test("input-password.html", '<input type="password" name="pwd" value="secret" />')

    def test_input_radio(self):
        self.ctx.locals.swallow = 'African'
        self.html_test("input-radio.html", """\
<input type="radio" name="swallow" value="African" checked />
<input type="radio" name="swallow" value="European" />
""")

    def test_input_radio_expr(self):
        self.ctx.locals.str = 'African'
        self.html_test("input-radio-expr.html", """\
<input type="radio" name="swallow" value="African" checked />
<input type="radio" name="swallow" value="European" />
""")

    def test_input_radio_valueexpr(self):
        self.ctx.locals.str = 'African'
        self.html_test("input-radio-valueexpr.html", """\
<input type="radio" name="swallow" value="African" checked />
""")

    def test_input_checkbox(self):
        self.ctx.locals.selected = ['two','four']
        self.ctx.locals.vexpr = 'four'
        self.html_test("input-checkbox.html", """\
<input type="checkbox" name="nums" value="one" />
<input type="checkbox" name="nums" value="two" checked />
<input type="checkbox" name="nums" value="three" />
<input type="checkbox" name="nums" value="four" checked />
""")

    def test_missing_multiple(self):
        self.tmpl_exc("missing-multiple.html")

    def test_illegal_multiple(self):
        self.tmpl_exc("illegal-multiple.html")

    def test_defined_single(self):
        self.tmpl_exc("defined-single.html")

    def test_defined_multiple(self):
        self.tmpl_exc("defined-multiple.html")

    def test_multiple_mixed_implicit(self):
        self.tmpl_exc("multiple-mixed-implicit.html")

    def test_missing_name(self):
        self.tmpl_exc("missing-name.html")

    def test_null_name(self):
        self.str_tmpl_exc('<al-input type="submit" />')
        self.str_tmpl_exc('<al-input name="" type="submit" />')
        self.str_tmpl_exc('<al-input name='' type="submit" />')
        self.str_tmpl_exc('<al-input nameexpr="\'\'" type="submit" />')
        self.str_tmpl_exc('<al-input name type="submit" />')
        self.str_tmpl_exc('<al-input name= type="submit" />')


class SelectCase(template_common.TemplateTestCommon):

    template_dir = "form"

    def test_select(self):
        self.ctx.locals.sel = 'spam'
        self.html_test("select.html", '<select name="sel"><option selected>spam</option><option>eggs</option></select>')

    def test_select_evaluate(self):
        self.ctx.locals.sel = 'spam'
        self.ctx.locals.val = 'spam'
        self.html_test("select-evaluate.html", '<select name="sel"><option selected>spam</option><option>eggs</option></select>')

    def test_select_value(self):
        self.ctx.locals.sel = 'spam'
        self.html_test("select-value.html", '<select name="sel"><option value="spam" selected>canned meat product</option><option>eggs</option></select>')

    def test_select_for(self):
        self.ctx.locals.sel = 'eggs'
        self.ctx.locals.values = 'spam', 'eggs'
        self.html_test("select-for.html", '<select name="sel"><option>spam</option><option selected>eggs</option></select>')

    def test_select_for_pair(self):
        self.ctx.locals.sel = 'eggs'
        self.ctx.locals.values = ('spam', 'canned meat product'), 'eggs'
        self.html_test("select-for.html", '<select name="sel"><option value="spam">canned meat product</option><option selected>eggs</option></select>')

    def test_select_for_label(self):
        self.ctx.locals.sel = 'eggs'
        self.ctx.locals.values = ('spam', 'canned meat product'), ('eggs', None)
        self.html_test("select-for-label.html", '<select name="sel"><option value="spam">canned meat product</option><option selected>eggs</option></select>')

    def test_select_for_content(self):
        self.ctx.locals.sel = 'eggs'
        self.ctx.locals.values = ('spam', 'canned meat product'), ('eggs', '')
        self.html_test("select-for-content.html", '<select name="sel"><option value="spam">canned meat product</option><option selected>eggs</option></select>')

    def test_select_select(self):
        self.tmpl_exc('select-select.html')

    def test_bare_option(self):
        self.tmpl_exc('bare-option.html')

    def test_select_name_expr(self):
        self.ctx.locals.val = 'spam'
        self.html_test("select-name-expr.html", '<select name="sel"><option selected>spam</option><option>eggs</option></select>')

    def test_select_optionexpr(self):
        self.ctx.locals.sel = '3'
        self.ctx.locals.opt = range(5)
        self.html_test("select-optionexpr.html", """\
<select name="sel"><option>0</option>
<option>1</option>
<option>2</option>
<option selected>3</option>
<option>4</option>
</select>""")

    def test_select_optionexpr_pairs(self):
        self.ctx.locals.sel = '2'
        self.ctx.locals.pairs = [(1, 'Spam'), (2, 'Eggs'), (3, 'Bacon')]
        self.html_test("select-optionexpr-pairs.html", """\
<select name="sel"><option value="1">Spam</option>
<option selected value="2">Eggs</option>
<option value="3">Bacon</option>
</select>""")

    def test_select_optionexpr_escaping(self):
        self.ctx.locals.sel = '<'
        self.ctx.locals.opt = ['&', '<', '>', '"']
        self.html_test("select-optionexpr.html", """\
<select name="sel"><option>&amp;</option>
<option selected>&lt;</option>
<option>&gt;</option>
<option>&quot;</option>
</select>""")

    def test_select_optionexpr_pair_escaping(self):
        self.ctx.locals.sel = '<'
        self.ctx.locals.pairs = [('&', '&'), ('<', '<'), ('>', '>'), ('"', '"')]
        self.html_test("select-optionexpr-pairs.html", """\
<select name="sel"><option value="&amp;">&amp;</option>
<option selected value="&lt;">&lt;</option>
<option value="&gt;">&gt;</option>
<option value="&quot;">&quot;</option>
</select>""")


class TextareaCase(template_common.TemplateTestCommon):

    template_dir = "form"

    def test_textarea(self):
        self.html_test("textarea.html", '<textarea name="msg">content\n</textarea>')

    def test_textarea_fromapp(self):
        self.ctx.locals.msg = "content\n"
        self.html_test("textarea-fromapp.html", '<textarea name="msg">content\n</textarea>')

    def test_textarea_fromapp_escaping(self):
        self.ctx.locals.msg = '&<>"\''
        self.html_test("textarea-fromapp.html", '<textarea name="msg">&amp;&lt;&gt;&quot;&#39;</textarea>')


class FormCase(template_common.TemplateTestCommon):

    template_dir = "form"

    def test_nested_form(self):
        self.tmpl_exc("nested-form.html")


if __name__ == '__main__':
    unittest.main()
