#
# Copyright 2001 by Object Craft P/L, Melbourne, Australia.
#
# LICENCE - see LICENCE file distributed with this software for details.
#
# 
# Test iterator constructs.
#
# $Id: iterator.py 15353 2010-01-18 09:09:09Z andrewm $

import unittest
import albatross
import template_common

class IteratorCase(template_common.TemplateTestCommon):

    template_dir = "iterator"

    def test_iterator(self):
        self.html_test("iterator.html", "01234")

    def test_var(self):
        self.html_test("var.html", "01234")

    def test_vars(self):
        self.html_test("vars.html", "0516273849")

    def test_anonymous(self):
        self.html_test("anonymous.html", "aaaaa")

    def test_nested(self):
        self.html_test("nested.html", "000102101112")

    def test_precreate(self):
        self.ctx.locals.i = albatross.ListIterator()
        self.ctx.locals.i.set_sequence(range(5))
        self.html_test("precreate.html", "01234")

    def test_unclosed(self):
        self.tmpl_exc("unclosed.html")

    def test_missingname(self):
        self.tmpl_exc("missingname.html")

    def test_noseq(self):
        self.tmpl_exc("noseq.html")

    def test_colsdown(self):
        self.html_test("down.html", "+035+146+2+")

    def test_colsacross(self):
        self.html_test("across.html", "+012+345+6+")

    def test_paging(self):
        # Fields are:
        #  i.pagesize()
        #  i.has_prevpage()
        #  i.has_nextpage()
        #  i.index()
        #  i.start()
        #  i.count()
        #  i.value()
        self.html_test("paging.html", 
                            "3 False True 0 0 0 0\n"
                            "3 False True 1 0 1 1\n"
                            "3 False True 2 0 2 2\n")
        self.ctx.locals.i.set_backdoor('nextpage', 'nextpage,i')
        self.expect_html(   "3 True True 3 3 0 3\n"
                            "3 True True 4 3 1 4\n"
                            "3 True True 5 3 2 5\n")
        self.ctx.locals.i.set_backdoor('nextpage', 'nextpage,i')
        self.expect_html(   "3 True False 6 6 0 6\n"
                            "3 True False 7 6 1 7\n"
                            "3 True False 8 6 2 8\n")
        self.ctx.locals.i.set_backdoor('prevpage', 'prevpage,i')
        self.expect_html(   "3 True True 3 3 0 3\n"
                            "3 True True 4 3 1 4\n"
                            "3 True True 5 3 2 5\n")


if __name__ == '__main__':
    unittest.main()
